Name: warewulf
Summary: A cluster implementation and management tool.
Version: 2.6.0
Release: 3
License: GPL
Group: System Environment/Clustering
Source: %{name}.tar.gz
BuildRoot: /var/tmp/%{name}-buildroot
Requires: dhcp tftp-server nfs-utils perl rsh
Requires: %{name}-tools = %{version}-%{release}
Requires: perl-Unix-Syslog
ExclusiveOS: linux

Provides: perl(Warewulf::Config) 
Provides: perl(Warewulf::PXE) 
Provides: perl(Warewulf::Util) 

%description
Warewulf is a customizable cluster build tool that facilitates the building
and administration of clusters. It uses RAM disks as the primary media for 
storing the nodes distribution so it is fast, volatile, and easily updated.

This is the main component to the Warewulf system. It contains the monitoring,
configuration and node build tools, and should be installed on the cluster
boot server (master).

%package tools
Summary: The Warewulf user tools
Group: System Enviornment/Clustering
Requires: perl-Term-Screen >= 1.02

%description tools
Warewulf is a customizable cluster build tool that facilitates the building
and administration of clusters. It uses RAM disks as the primary media for 
storing the nodes distribution so it is fast, volatile, and easily updated.

This provides the warewulf user tools, and is split out from the main package
to allow for multiple interactive login nodes and remote monitoring nodes.

%package wulfd
Summary: The Warewulf node daemon
Group: System Enviornment/Daemons
Prereq: chkconfig

%description wulfd
Warewulf is a customizable cluster build tool that facilitates the building
and administration of clusters. It uses RAM disks as the primary media for 
storing the nodes distribution so it is fast, volatile, and easily updated.

This is the node daemon component to the Warewulf system. 

%package proxy
Summary: The Warewulf node daemon proxy service
Group: System Enviornment/Daemons
Prereq: chkconfig

%description proxy
Warewulf is a customizable cluster build tool that facilitates the building
and administration of clusters. It uses RAM disks as the primary media for
storing the nodes distribution so it is fast, volatile, and easily updated.

Wwproxy aggregates multiple warewulf daemons together and will also
lesson the load on warewulfd by only polling the warewulfd every X
seconds nomatter how many users are hitting it. It can also distribute
the Warewulf node stats in a ganglia capable XML format suitable for
being slurped by gmetad.

%package web
Summary: The Warewulf web frontend
Group: System Enviornment/monitoring
Requires: httpd

%description web
Warewulf is a customizable cluster build tool that facilitates the building
and administration of clusters. It uses RAM disks as the primary media for
storing the nodes distribution so it is fast, volatile, and easily updated.

The web frontend provides an interface to one or more Warewulf clusters.

%prep
%setup -n %{name} -T -c -a 0
%build
%{__make} %{?mflags}

%install
%{__make} install DESTDIR=$RPM_BUILD_ROOT %{?mflags_install}

%{__mkdir_p} $RPM_BUILD_ROOT/var/warewulf/vnfs
%{__mkdir_p} $RPM_BUILD_ROOT/srv/vnfs

echo "Warewulf release %{version}-%{release}" > \
   $RPM_BUILD_ROOT/etc/warewulf-release

%pre
if rpm -q warewulf | grep 2.4 >/dev/null 2>&1 ; then
   echo "Warewulf %{version} is not intended to update previous versions."
   echo "Remove the previous version, and then install this version fresh"
   echo "backing up the previous /etc/warewulf directory and then"
   echo "reconfiguring by hand."
   exit 1
fi

%pre tools
if rpm -q warewulf-tools | grep 2.4 >/dev/null 2>&1 ; then
   echo "Warewulf %{version} is not intended to update previous versions."
   echo "Remove the previous version, and then install this version fresh"
   echo "backing up the previous /etc/warewulf directory and then"
   echo "reconfiguring by hand."
   exit 1
fi

%pre wulfd
if rpm -q warewulf-wulfd | grep 2.4 >/dev/null 2>&1 ; then
   echo "Warewulf %{version} is not intended to update previous versions."
   echo "Remove the previous version, and then install this version fresh"
   echo "backing up the previous /etc/warewulf directory and then"
   echo "reconfiguring by hand."
   exit 1
fi

%post
/sbin/chkconfig --add warewulf
/sbin/chkconfig warewulf on
/sbin/chkconfig --add vnfsd
/sbin/chkconfig vnfsd on
/sbin/chkconfig --add wwnewd
/sbin/chkconfig wwnewd on

%post wulfd
chkconfig --add wulfd
chkconfig wulfd on

%post web
/sbin/service httpd condrestart >/dev/null 2>&1 ||:
/sbin/service apache2 condrestart >/dev/null 2>&1 ||:

%preun
if [ $1 -eq '0' ]; then
   /sbin/service warewulf stop >/dev/null 2>&1
   chkconfig --del warewulf
   /sbin/service vnfsd stop >/dev/null 2>&1
   chkconfig --del vnfsd
   chkconfig --del wwnewd
fi

%preun wulfd
if [ $1 -eq '0' ]; then
   /etc/rc.d/init.d/wulfd stop >/dev/null 2>&1
   chkconfig --del wulfd
fi

%preun proxy
if [ $1 -eq '0' ]; then
   /etc/rc.d/init.d/wwproxy stop >/dev/null 2>&1
   chkconfig --del wwproxy
fi

%postun web
/sbin/service httpd condrestart >/dev/null 2>&1 ||:
/sbin/service apache2 condrestart >/dev/null 2>&1 ||:

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc Readme Copyright Credits Install License Todo
%config() %{_sysconfdir}/warewulf-release
%config(noreplace) %{_sysconfdir}/warewulf/wwinitrd.config
%config(noreplace) %{_sysconfdir}/warewulf/master.conf
%config(noreplace) %{_sysconfdir}/warewulf/vnfs/*
%config(noreplace) %{_sysconfdir}/warewulf/nodes/*
%config(noreplace) %{_sysconfdir}/sysconfig/vnfsd
%config /usr/lib/warewulf/wwinitrc
%config /usr/lib/warewulf/wwpostrc
%dir /srv/vnfs
%dir /var/warewulf
%dir /var/warewulf/vnfs
%dir /var/warewulf/syncs
%dir /usr/lib/warewulf
%dir /usr/lib/warewulf/Warewulf
%dir /usr/lib/warewulf/modules
%dir /usr/share/warewulf
%{_sysconfdir}/rc.d/init.d/warewulf
%{_sysconfdir}/rc.d/init.d/vnfsd
%{_sysconfdir}/rc.d/init.d/wwnewd
/usr/lib/warewulf/Warewulf/*
/usr/lib/warewulf/modules/*
/usr/share/warewulf/*
%{_sbindir}/warewulfd
%{_sbindir}/vnfsd
%{_sbindir}/wwmkinitrd
%{_sbindir}/wwnodes
%{_sbindir}/wwnewd
%{_sbindir}/wwvnfs
%{_sbindir}/wwinit
%{_sbindir}/wwdebug
%{_bindir}/wwps
/var/warewulf/wwinitrd
%{_mandir}/man8/wwinit.8.gz
%{_mandir}/man8/wwnodes.8.gz
%{_mandir}/man8/wwvnfs.8.gz
%{_mandir}/man8/wwmkinitrd.8.gz
%{_mandir}/man5/master.conf.5.gz

%files tools
%defattr(-,root,root)
%doc Readme Copyright Credits Install License Todo
%config(noreplace) %{_sysconfdir}/warewulf/client.conf
/usr/lib/warewulf/Warewulf/*
%{_bindir}/wwlist
%{_bindir}/wwstats
%{_bindir}/wwsummary
%{_bindir}/wwtop
%{_bindir}/wwmpirun
%{_mandir}/man8/wwlist.8.gz
%{_mandir}/man8/wwmpirun.8.gz
%{_mandir}/man8/wwstats.8.gz
%{_mandir}/man8/wwtop.8.gz

%files wulfd
%defattr(-,root,root)
%doc Readme Copyright Credits Install License Todo
%config(noreplace) %{_sysconfdir}/warewulf/node-partitions
%config(noreplace) %{_sysconfdir}/sysconfig/wulfd
%{_sysconfdir}/rc.d/init.d/wulfd
%{_sbindir}/wulfd

%files proxy
%defattr(-,root,root)
%doc Readme Copyright Credits Install License Todo
%config(noreplace) %{_sysconfdir}/sysconfig/wwproxy
%{_sysconfdir}/warewulf/wwproxy.config
%{_sysconfdir}/rc.d/init.d/wwproxy
%{_sbindir}/wwproxy

%files web
%defattr(-,root,root)
%doc Readme Copyright Credits Install License Todo
%config(noreplace) %{_sysconfdir}/httpd/conf.d/warewulf.conf
%{_datadir}/warewulf/cgi
%{_datadir}/warewulf/images
/usr/lib/warewulf/Warewulf/Status.pm


%changelog
